@@ -55,7 +55,7 @@ class TestToTypeConversion(TestCase):
     def test_to_same_unit(self):
         """bitmath type converted to the same unit is properly converted"""
         to_kib = self.kib.to_KiB()
-        self.assertIsInstance(to_kib, bitmath.KiB)
+        self.assertIs(type(to_kib), bitmath.KiB)
 
     def test_from_other(self):
         """MiB object from_other object"""
@@ -65,145 +65,145 @@ class TestToTypeConversion(TestCase):
     # to b's
     def test_to_Bit(self):
         """Convert to Bit"""
-        self.assertIsInstance(self.kb.to_Bit(), bitmath.Bit)
+        self.assertIs(type(self.kb.to_Bit()), bitmath.Bit)
 
     def test_to_Byte(self):
         """Convert to Byte"""
-        self.assertIsInstance(self.kb.to_Byte(), bitmath.Byte)
+        self.assertIs(type(self.kb.to_Byte()), bitmath.Byte)
 
     ##################################################################
     # to k's
     def test_to_KiB(self):
         """Convert to KiB"""
         to_kib = self.mib.to_KiB()
-        self.assertIsInstance(to_kib, bitmath.KiB)
+        self.assertIs(type(to_kib), bitmath.KiB)
 
     def test_to_Kib(self):
         """Convert to Kib"""
         to_kib = self.mib.to_Kib()
-        self.assertIsInstance(to_kib, bitmath.Kib)
+        self.assertIs(type(to_kib), bitmath.Kib)
 
     def test_to_kb(self):
         """Convert to kb"""
         to_kb = self.mib.to_kb()
-        self.assertIsInstance(to_kb, bitmath.kb)
+        self.assertIs(type(to_kb), bitmath.kb)
 
     ##################################################################
     # to m's
     def test_to_MiB(self):
         """Convert a bitmath GiB into a MiB"""
         to_mib = self.gib.to_MiB()
-        self.assertIsInstance(to_mib, bitmath.MiB)
+        self.assertIs(type(to_mib), bitmath.MiB)
 
     def test_to_Mib(self):
         """Convert a bitmath GiB into a Mib"""
         to_mib = self.gib.to_Mib()
-        self.assertIsInstance(to_mib, bitmath.Mib)
+        self.assertIs(type(to_mib), bitmath.Mib)
 
     def test_to_MB(self):
         """Convert a bitmath GiB into a MB"""
         to_mb = self.gib.to_MB()
-        self.assertIsInstance(to_mb, bitmath.MB)
+        self.assertIs(type(to_mb), bitmath.MB)
 
     def test_to_Mb(self):
         """Convert a bitmath GiB into a Mb"""
         to_mb = self.gib.to_Mb()
-        self.assertIsInstance(to_mb, bitmath.Mb)
+        self.assertIs(type(to_mb), bitmath.Mb)
 
     ##################################################################
     # to g's
     def test_to_GiB(self):
         """Convert a bitmath TiB into a GiB"""
         to_gib = self.tib.to_GiB()
-        self.assertIsInstance(to_gib, bitmath.GiB)
+        self.assertIs(type(to_gib), bitmath.GiB)
 
     def test_to_Gib(self):
         """Convert a bitmath GiB into a Gib"""
         to_gib = self.gib.to_Gib()
-        self.assertIsInstance(to_gib, bitmath.Gib)
+        self.assertIs(type(to_gib), bitmath.Gib)
 
     def test_to_GB(self):
         """Convert a bitmath GiB into a GB"""
         to_gb = self.gib.to_GB()
-        self.assertIsInstance(to_gb, bitmath.GB)
+        self.assertIs(type(to_gb), bitmath.GB)
 
     def test_to_Gb(self):
         """Convert a bitmath GiB into a Gb"""
         to_gb = self.gib.to_Gb()
-        self.assertIsInstance(to_gb, bitmath.Gb)
+        self.assertIs(type(to_gb), bitmath.Gb)
 
     ##################################################################
     # to t's
     def test_to_TiB(self):
         """Convert a bitmath PiB into a TiB"""
         to_tib = self.pib.to_TiB()
-        self.assertIsInstance(to_tib, bitmath.TiB)
+        self.assertIs(type(to_tib), bitmath.TiB)
 
     def test_to_Tib(self):
         """Convert a bitmath GiB into a Tib"""
         to_tib = self.gib.to_Tib()
-        self.assertIsInstance(to_tib, bitmath.Tib)
+        self.assertIs(type(to_tib), bitmath.Tib)
 
     def test_to_TB(self):
         """Convert a bitmath GiB into a TB"""
         to_tb = self.gib.to_TB()
-        self.assertIsInstance(to_tb, bitmath.TB)
+        self.assertIs(type(to_tb), bitmath.TB)
 
     def test_to_Tb(self):
         """Convert a bitmath GiB into a Tb"""
         to_tb = self.gib.to_Tb()
-        self.assertIsInstance(to_tb, bitmath.Tb)
+        self.assertIs(type(to_tb), bitmath.Tb)
 
     ##################################################################
     # to p's
     def test_to_PiB(self):
         """Convert a bitmath TiB into a PiB"""
         to_pib = self.tib.to_PiB()
-        self.assertIsInstance(to_pib, bitmath.PiB)
+        self.assertIs(type(to_pib), bitmath.PiB)
 
     def test_to_Pib(self):
         """Convert a bitmath GiB into a PiB"""
         to_pib = self.gib.to_Pib()
-        self.assertIsInstance(to_pib, bitmath.Pib)
+        self.assertIs(type(to_pib), bitmath.Pib)
 
     def test_to_PB(self):
         """Convert a bitmath GiB into a PB"""
         to_pb = self.gib.to_PB()
-        self.assertIsInstance(to_pb, bitmath.PB)
+        self.assertIs(type(to_pb), bitmath.PB)
 
     def test_to_Pb(self):
         """Convert a bitmath GiB into a Pb"""
         to_pb = self.gib.to_Pb()
-        self.assertIsInstance(to_pb, bitmath.Pb)
+        self.assertIs(type(to_pb), bitmath.Pb)
 
     ##################################################################
     # to e's
     def test_to_EiB(self):
         """Convert a bitmath PiB into a EiB"""
         to_eib = self.pib.to_EiB()
-        self.assertIsInstance(to_eib, bitmath.EiB)
+        self.assertIs(type(to_eib), bitmath.EiB)
 
     def test_to_Eib(self):
         """Convert a bitmath GiB into a Eib"""
         to_eib = self.gib.to_Eib()
-        self.assertIsInstance(to_eib, bitmath.Eib)
+        self.assertIs(type(to_eib), bitmath.Eib)
 
     def test_to_EB(self):
         """Convert a bitmath GiB into a EB"""
         to_eb = self.gib.to_EB()
-        self.assertIsInstance(to_eb, bitmath.EB)
+        self.assertIs(type(to_eb), bitmath.EB)
 
     def test_to_Eb(self):
         """Convert a bitmath GiB into a Eb"""
         to_eb = self.gib.to_Eb()
-        self.assertIsInstance(to_eb, bitmath.Eb)
+        self.assertIs(type(to_eb), bitmath.Eb)
 
     ##################################################################
     # to other stuff
     def test_to_mib_from_bit(self):
         """Convert a bitmath Bit into a MiB"""
         to_mib = self.bit.to_MiB()
-        self.assertIsInstance(to_mib, bitmath.MiB)
+        self.assertIs(type(to_mib), bitmath.MiB)
 
     def test_converted_up_bitmath_value_equivalency(self):
         """Converted up type has an equivalent value to the original"""
